==> qpc_admob-0.0.5.tar.gz: android/src/main/java/com/qpc/qpc_admob/RewardedVideoAdWrapper.java <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package com.qpc.qpc_admob;

import android.app.Activity;
import android.util.Log;
import android.view.View;
import android.widget.Button;

import com.bytedance.sdk.openadsdk.AdSlot;
import com.bytedance.sdk.openadsdk.TTAdConstant;
import com.bytedance.sdk.openadsdk.TTAdManager;
import com.bytedance.sdk.openadsdk.TTAdNative;
import com.bytedance.sdk.openadsdk.TTAdSdk;
import com.bytedance.sdk.openadsdk.TTAppDownloadListener;
import com.bytedance.sdk.openadsdk.TTInteractionAd;
import com.bytedance.sdk.openadsdk.TTNativeExpressAd;
import com.bytedance.sdk.openadsdk.TTRewardVideoAd;


import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodChannel;

public class RewardedVideoAdWrapper implements  TTAdNative.RewardVideoAdListener, TTRewardVideoAd.RewardAdInteractionListener, TTAppDownloadListener {
  private static final String TAG = "flutter";


  private final MethodChannel channel;
  Activity activity;
  private Status status;
  private TTAdNative mTTAdNative;
  private TTRewardVideoAd mttRewardVideoAd;
  private Button mLoadAdVertical;
  private Button mShowAd;
  private String mHorizontalCodeId;
  private String mVerticalCodeId;

  @Override
  public void onError(int code, String message) {
    TToast.show(activity,message);
  }

  @Override
  public void onRewardVideoAdLoad(TTRewardVideoAd ttRewardVideoAd) {
    TToast.show(activity, "rewardVideoAd loaded");
    status = Status.LOADED;
    channel.invokeMethod("onRewardedVideoAdLoaded", argumentsMap());
    mttRewardVideoAd = ttRewardVideoAd;
    ttRewardVideoAd.setDownloadListener(this);
    ttRewardVideoAd.setRewardAdInteractionListener(this);
    mttRewardVideoAd.showRewardVideoAd(activity, TTAdConstant.RitScenes.GAME_START_BONUS,"解锁");

  }

  @Override
  public void onRewardVideoCached() {
    TToast.show(activity,"rewardVideoAd video cached");

  }

  @Override
  public void onIdle() {

  }

  @Override
  public void onDownloadActive(long l, long l1, String s, String s1) {

  }

  @Override
  public void onDownloadPaused(long l, long l1, String s, String s1) {

  }

  @Override
  public void onDownloadFailed(long l, long l1, String s, String s1) {

  }

  @Override
  public void onDownloadFinished(long l, String s, String s1) {

  }

  @Override
  public void onInstalled(String s, String s1) {

  }

  @Override
  public void onAdShow() {
    TToast.show(activity, "rewardVideoAd show");
    channel.invokeMethod("onRewardedVideoAdOpened", argumentsMap());

  }

  @Override
  public void onAdVideoBarClick() {
    TToast.show(activity, "rewardVideoAd bar click");
  }

  @Override
  public void onAdClose() {
    TToast.show(activity, "rewardVideoAd close");
    this.status = Status.CREATED;
    channel.invokeMethod("onRewardedVideoAdClosed", argumentsMap());
  }

  //视频播放完成回调
  @Override
  public void onVideoComplete() {
    TToast.show(activity, "rewardVideoAd complete");
    channel.invokeMethod("onRewardedVideoCompleted", argumentsMap());
    channel.invokeMethod(
            "onRewarded",
            argumentsMap("rewardType", 1, "rewardAmount", 1));
  }

  @Override
  public void onVideoError() {
    TToast.show(activity, "rewardVideoAd error");
    Log.w(TAG, "onRewardedVideoAdFailedToLoad "  );
    status = Status.FAILED;
    channel.invokeMethod("onRewardedVideoAdFailedToLoad", argumentsMap());
  }

  //视频播放完成后，奖励验证回调，rewardVerify：是否有效，rewardAmount：奖励梳理，rewardName：奖励名称
  @Override
  public void onRewardVerify(boolean rewardVerify, int rewardAmount, String rewardName) {
    TToast.show(activity, "verify:" + rewardVerify + " amount:" + rewardAmount +
            " name:" + rewardName);
    channel.invokeMethod(
            "onRewarded",
            argumentsMap("rewardType", rewardName, "rewardAmount", rewardAmount));
  }

  @Override
  public void onSkippedVideo() {
    TToast.show(activity, "rewardVideoAd has onSkippedVideo");
  }

  enum Status {
    CREATED,
    LOADING,
    FAILED,
    LOADED
  }

  public RewardedVideoAdWrapper(Activity activity, MethodChannel channel) {
    this.activity= activity;
    this.channel = channel;
    this.status = Status.CREATED;
    TTAdManager ttAdManager =  TTAdSdk.getAdManager();
    //step2:(可选，强烈建议在合适的时机调用):申请部分权限，如read_phone_state,防止获取不了imei时候，下载类广告没有填充的问题。
    ttAdManager.requestPermissionIfNecessary(activity);
    //step3:创建TTAdNative对象,用于调用广告请求接口
    this.mTTAdNative = ttAdManager.createAdNative(activity);
  }

  Status getStatus() {
    return status;
  }

  public void load(String adUnitId,String userId, Map<String, Object> targetingInfo) {
    status = Status.LOADING;
    AdSlot adSlot = new AdSlot.Builder()
            .setCodeId(adUnitId)
            .setSupportDeepLink(true)
            .setImageAcceptedSize(1080, 1920)
            .setRewardName("游戏解锁") //奖励的名称
            .setRewardAmount(1)  //奖励的数量
            .setUserID(userId)//用户id,必传参数
            .setMediaExtra("media_extra") //附加参数，可选
            .setOrientation(TTAdConstant.HORIZONTAL) //必填参数，期望视频的播放方向：TTAdConstant.HORIZONTAL 或 TTAdConstant.VERTICAL
            .build();
    AdRequestBuilderFactory factory = new AdRequestBuilderFactory(targetingInfo);
    mTTAdNative.loadRewardVideoAd(adSlot, (TTAdNative.RewardVideoAdListener) this);
  }

  public void show() {
    if (mttRewardVideoAd !=null ) {
      mttRewardVideoAd.showRewardVideoAd(activity, TTAdConstant.RitScenes.GAME_START_BONUS,"解锁");
    }
  }

  private Map<String, Object> argumentsMap(Object... args) {
    Map<String, Object> arguments = new HashMap<String, Object>();
    for (int i = 0; i < args.length; i += 2) arguments.put(args[i].toString(), args[i + 1]);
    return arguments;
  }
}

==> qpc_admob-0.0.6.tar.gz: android/src/main/java/com/qpc/qpc_admob/RewardedVideoAdWrapper.java <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package com.qpc.qpc_admob;

import android.app.Activity;
import android.util.Log;
import android.view.View;
import android.widget.Button;

import com.bytedance.sdk.openadsdk.AdSlot;
import com.bytedance.sdk.openadsdk.TTAdConstant;
import com.bytedance.sdk.openadsdk.TTAdManager;
import com.bytedance.sdk.openadsdk.TTAdNative;
import com.bytedance.sdk.openadsdk.TTAdSdk;
import com.bytedance.sdk.openadsdk.TTAppDownloadListener;
import com.bytedance.sdk.openadsdk.TTInteractionAd;
import com.bytedance.sdk.openadsdk.TTNativeExpressAd;
import com.bytedance.sdk.openadsdk.TTRewardVideoAd;


import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodChannel;

public class RewardedVideoAdWrapper implements  TTAdNative.RewardVideoAdListener, TTRewardVideoAd.RewardAdInteractionListener, TTAppDownloadListener {
  private static final String TAG = "qpc";


  private final MethodChannel channel;
  Activity activity;
  private Status status;
  private TTAdNative mTTAdNative;
  private TTRewardVideoAd mttRewardVideoAd;
  private Button mLoadAdVertical;
  private Button mShowAd;
  private String mHorizontalCodeId;
  private String mVerticalCodeId;

  @Override
  public void onError(int code, String message) {
    TToast.show(activity,message);
  }

  @Override
  public void onRewardVideoAdLoad(TTRewardVideoAd ttRewardVideoAd) {
    Log.w(TAG, "rewardVideoAd loaded: ");
    status = Status.LOADED;
    channel.invokeMethod("onRewardedVideoAdLoaded", argumentsMap());
    mttRewardVideoAd = ttRewardVideoAd;
    ttRewardVideoAd.setDownloadListener(this);
    ttRewardVideoAd.setRewardAdInteractionListener(this);
    mttRewardVideoAd.showRewardVideoAd(activity, TTAdConstant.RitScenes.GAME_START_BONUS,"解锁");

  }

  @Override
  public void onRewardVideoCached() {
    Log.w(TAG, "rewardVideoAd video cached");
    if (mttRewardVideoAd !=null ) {
      mttRewardVideoAd.showRewardVideoAd(activity, TTAdConstant.RitScenes.GAME_START_BONUS,"解锁");
    }

  }

  @Override
  public void onIdle() {
    Log.w(TAG, "rewardVideoAd onIdle");

  }

  @Override
  public void onDownloadActive(long l, long l1, String s, String s1) {
    Log.w(TAG, "rewardVideoAd onIdle");
  }

  @Override
  public void onDownloadPaused(long l, long l1, String s, String s1) {
    Log.w(TAG, "rewardVideoAd onDownloadPaused");
  }

  @Override
  public void onDownloadFailed(long l, long l1, String s, String s1) {
    Log.w(TAG, "rewardVideoAd onDownloadFailed");

  }

  @Override
  public void onDownloadFinished(long l, String s, String s1) {
    Log.w(TAG, "rewardVideoAd onDownloadFinished");
  }

  @Override
  public void onInstalled(String s, String s1) {
    Log.w(TAG, "rewardVideoAd onInstalled");

  }

  @Override
  public void onAdShow() {
    Log.w(TAG, "rewardVideoAd onAdShow");
    channel.invokeMethod("onRewardedVideoAdOpened", argumentsMap());

  }

  @Override
  public void onAdVideoBarClick() {
    Log.w(TAG, "rewardVideoAd bar click");
  }

  @Override
  public void onAdClose() {

    Log.w(TAG, "rewardVideoAd  close");
    this.status = Status.CREATED;
    channel.invokeMethod("onRewardedVideoAdClosed", argumentsMap());
  }

  //视频播放完成回调
  @Override
  public void onVideoComplete() {

    Log.w(TAG, "rewardVideoAd complete");
    channel.invokeMethod("onRewardedVideoCompleted", argumentsMap());
//    channel.invokeMethod(
//            "onRewarded",
//            argumentsMap("rewardType", 1, "rewardAmount", 1));
  }

  @Override
  public void onVideoError() {
    Log.w(TAG, "rewardVideoAd error "  );
    status = Status.FAILED;
    channel.invokeMethod("onRewardedVideoAdFailedToLoad", argumentsMap());
  }

  //视频播放完成后，奖励验证回调，rewardVerify：是否有效，rewardAmount：奖励梳理，rewardName：奖励名称
  @Override
  public void onRewardVerify(boolean rewardVerify, int rewardAmount, String rewardName) {

    Log.w(TAG, "rewardVideoAd  "+"verify:" + rewardVerify + " amount:" + rewardAmount +
            " name:" + rewardName );
    channel.invokeMethod(
            "onRewarded",
            argumentsMap("rewardType", rewardName, "rewardAmount", rewardAmount));
  }

  @Override
  public void onSkippedVideo() {
    Log.w(TAG, "rewardVideoAd has onSkippedVideo  ");
  }

  enum Status {
    CREATED,
    LOADING,
    FAILED,
    LOADED
  }

  public RewardedVideoAdWrapper(Activity activity, MethodChannel channel) {
    this.activity= activity;
    this.channel = channel;
    this.status = Status.CREATED;
    TTAdManager ttAdManager =  TTAdSdk.getAdManager();
    //step2:(可选，强烈建议在合适的时机调用):申请部分权限，如read_phone_state,防止获取不了imei时候，下载类广告没有填充的问题。
    ttAdManager.requestPermissionIfNecessary(activity);
    //step3:创建TTAdNative对象,用于调用广告请求接口
    this.mTTAdNative = ttAdManager.createAdNative(activity);
  }

  Status getStatus() {
    return status;
  }

  public void load(String adUnitId,String userId, Map<String, Object> targetingInfo) {
    status = Status.LOADING;
    AdSlot adSlot = new AdSlot.Builder()
            .setCodeId(adUnitId)
            .setSupportDeepLink(true)
            .setImageAcceptedSize(1080, 1920)
            .setRewardName("游戏解锁") //奖励的名称
            .setRewardAmount(1)  //奖励的数量
            .setUserID(userId)//用户id,必传参数
            .setMediaExtra("media_extra") //附加参数，可选
            .setOrientation(TTAdConstant.HORIZONTAL) //必填参数，期望视频的播放方向：TTAdConstant.HORIZONTAL 或 TTAdConstant.VERTICAL
            .build();
    AdRequestBuilderFactory factory = new AdRequestBuilderFactory(targetingInfo);
    mTTAdNative.loadRewardVideoAd(adSlot, (TTAdNative.RewardVideoAdListener) this);
  }

  public void show() {
    if (mttRewardVideoAd !=null ) {
      mttRewardVideoAd.showRewardVideoAd(activity, TTAdConstant.RitScenes.GAME_START_BONUS,"解锁");
    }
  }

  private Map<String, Object> argumentsMap(Object... args) {
    Map<String, Object> arguments = new HashMap<String, Object>();
    for (int i = 0; i < args.length; i += 2) arguments.put(args[i].toString(), args[i + 1]);
    return arguments;
  }
}
